@@ -9,6 +9,8 @@ describe("DNS Validated Certificate Handler", () => {
   const handler = require("../lib/dns-cert-validator");
   const nock = require("nock");
   const ResponseURL = "https://cloudwatch-response-mock.example.com/";
+  const LogGroup = "/aws/lambda/testLambda";
+  const LogStream = "/2021/06/28/[$LATEST]9b93a7dca7344adeb193d15c092dbbfd";
 
   let origLog = console.log;
   const testRequestId = "f4ef1b10-c39a-44e3-99c0-fbf7e53c3943";
@@ -26,13 +28,19 @@ describe("DNS Validated Certificate Handler", () => {
     "frontend": ["v1.${testAppName}.${testDomainName}"],
     "backend": ["v2.${testDomainName}"]
   }`;
-  const testSANs = ["*.test.myapp.example.com", "v1.myapp.example.com", "v2.example.com"];
+  const testSANs = [
+    "*.test.myapp.example.com",
+    "v1.myapp.example.com",
+    "v2.example.com",
+  ];
   const testCopilotTags = [
     { Key: "copilot-application", Value: testAppName },
     { Key: "copilot-environment", Value: testEnvName },
   ];
   const testCertificateArn =
     "arn:aws:acm:region:123456789012:certificate/12345678-1234-1234-1234-123456789012";
+  const testOtherCertificateArn =
+    "arn:aws:acm:region:123456789012:certificate/1234-1234-123456789012-12345678-1234";
   const testRRName = "_3639ac514e785e898d2646601fa951d5.example.com";
   const testRRValue1 = "_x1.acm-validations.aws";
   const testRRValue2 = "_x2.acm-validations.aws";
@@ -57,23 +65,6 @@ describe("DNS Validated Certificate Handler", () => {
       },
     ],
   };
-  const testDeleteRecordChangebatch2 = {
-    Changes: [
-      {
-        Action: "DELETE",
-        ResourceRecordSet: {
-          Name: testRRName,
-          Type: "CNAME",
-          TTL: 60,
-          ResourceRecords: [
-            {
-              Value: testRRValue2,
-            },
-          ],
-        },
-      },
-    ],
-  };
   const testDeleteRecordChangebatch3 = {
     Changes: [
       {
@@ -162,6 +153,35 @@ describe("DNS Validated Certificate Handler", () => {
       },
     },
   ];
+  const newCertValidatorOptionsWithoutV2 = [
+    {
+      DomainName: `${testEnvName}.${testAppName}.${testDomainName}`,
+      ValidationStatus: "SUCCESS",
+      ResourceRecord: {
+        Name: testRRName,
+        Type: "CNAME",
+        Value: testRRValue1,
+      },
+    },
+    {
+      DomainName: `*.${testEnvName}.${testAppName}.${testDomainName}`,
+      ValidationStatus: "SUCCESS",
+      ResourceRecord: {
+        Name: testRRName,
+        Type: "CNAME",
+        Value: testRRValue1,
+      },
+    },
+    {
+      DomainName: `v1.${testAppName}.${testDomainName}`,
+      ValidationStatus: "PENDING_VALIDATION",
+      ResourceRecord: {
+        Name: testRRName,
+        Type: "CNAME",
+        Value: testRRValue2,
+      },
+    },
+  ];
   const newCertValidateOptions = [
     {
       DomainName: `${testEnvName}.${testAppName}.${testDomainName}`,
@@ -203,6 +223,8 @@ describe("DNS Validated Certificate Handler", () => {
 
   beforeEach(() => {
     handler.withDefaultResponseURL(ResponseURL);
+    handler.withDefaultLogGroup(LogGroup);
+    handler.withDefaultLogStream(LogStream);
     handler.withWaiter(function () {
       // Mock waiter is merely a self-fulfilling promise
       return {
@@ -229,7 +251,8 @@ describe("DNS Validated Certificate Handler", () => {
       .put("/", (body) => {
         return (
           body.Status === "FAILED" &&
-          body.Reason === "Unsupported request type undefined"
+          body.Reason ===
+            "Unsupported request type undefined (Log: /aws/lambda/testLambda/2021/06/28/[$LATEST]9b93a7dca7344adeb193d15c092dbbfd)"
         );
       })
       .reply(200);
@@ -257,7 +280,10 @@ describe("DNS Validated Certificate Handler", () => {
       .put("/", (body) => {
         return (
           body.Status === "FAILED" &&
-          body.Reason === "Unsupported request type " + bogusType
+          body.Reason ===
+            "Unsupported request type " +
+              bogusType +
+              " (Log: /aws/lambda/testLambda/2021/06/28/[$LATEST]9b93a7dca7344adeb193d15c092dbbfd)"
         );
       })
       .reply(200);
@@ -340,7 +366,7 @@ describe("DNS Validated Certificate Handler", () => {
           Region: "us-east-1",
           RootDNSRole: testRootDNSRole,
         },
-        OldResourceProperties: {}
+        OldResourceProperties: {},
       })
       .expectResolve(() => {
         sinon.assert.calledWith(
@@ -400,7 +426,9 @@ describe("DNS Validated Certificate Handler", () => {
   test("Update operation quits early if cert doesn't change", () => {
     const request = nock(ResponseURL)
       .put("/", (body) => {
-        return body.Status === "SUCCESS";
+        return (
+          body.Status === "SUCCESS" && body.PhysicalResourceId === "mockCertArn"
+        );
       })
       .reply(200);
 
@@ -408,6 +436,7 @@ describe("DNS Validated Certificate Handler", () => {
       .event({
         RequestType: "Update",
         RequestId: testRequestId,
+        PhysicalResourceId: "mockCertArn",
         ResourceProperties: {
           AppName: testAppName,
           EnvName: testEnvName,
@@ -763,7 +792,7 @@ describe("DNS Validated Certificate Handler", () => {
       });
   });
 
-  test("Delete operation deletes the last legacy cert", () => {
+  test("Delete operation deletes the last cert", () => {
     const describeCertificateFake = sinon.fake.resolves({
       Certificate: {
         CertificateArn: testCertificateArn,
@@ -780,6 +809,7 @@ describe("DNS Validated Certificate Handler", () => {
       CertificateSummaryList: [
         {
           DomainName: `${testEnvName}.${testAppName}.${testDomainName}`,
+          CertificateArn: testCertificateArn,
         },
       ],
       NextToken: "some token",
@@ -855,11 +885,18 @@ describe("DNS Validated Certificate Handler", () => {
       });
   });
 
-  test("Delete operation deletes the legacy cert but not the last", () => {
-    const describeCertificateFake = sinon.fake.resolves({
+  test("Delete operation deletes the cert without record removal", () => {
+    const describeCertificateFake = sinon.stub();
+    describeCertificateFake.onFirstCall().resolves({
       Certificate: {
         CertificateArn: testCertificateArn,
-        DomainValidationOptions: legacyCertValidatorOptions,
+        DomainValidationOptions: newCertValidatorOptionsWithoutV2,
+      },
+    });
+    describeCertificateFake.onSecondCall().resolves({
+      Certificate: {
+        CertificateArn: testOtherCertificateArn,
+        DomainValidationOptions: newCertValidateOptions,
       },
     });
     AWS.mock("ACM", "describeCertificate", describeCertificateFake);
@@ -872,9 +909,11 @@ describe("DNS Validated Certificate Handler", () => {
       CertificateSummaryList: [
         {
           DomainName: `${testEnvName}.${testAppName}.${testDomainName}`,
+          CertificateArn: testCertificateArn,
         },
         {
           DomainName: `${testEnvName}.${testAppName}.${testDomainName}`,
+          CertificateArn: testOtherCertificateArn,
         },
       ],
     });
@@ -908,6 +947,12 @@ describe("DNS Validated Certificate Handler", () => {
           })
         );
         sinon.assert.calledWith(listCertificatesFake, sinon.match({}));
+        sinon.assert.calledWith(
+          describeCertificateFake,
+          sinon.match({
+            CertificateArn: testOtherCertificateArn,
+          })
+        );
         sinon.assert.calledWith(
           deleteCertificateFake,
           sinon.match({
@@ -918,13 +963,20 @@ describe("DNS Validated Certificate Handler", () => {
       });
   });
 
-  test("Delete operation deletes the last new cert", () => {
-    const describeCertificateFake = sinon.fake.resolves({
+  test("Delete operation deletes the cert with record removal", () => {
+    const describeCertificateFake = sinon.stub();
+    describeCertificateFake.onFirstCall().resolves({
       Certificate: {
         CertificateArn: testCertificateArn,
         DomainValidationOptions: newCertValidateOptions,
       },
     });
+    describeCertificateFake.onSecondCall().resolves({
+      Certificate: {
+        CertificateArn: testOtherCertificateArn,
+        DomainValidationOptions: newCertValidatorOptionsWithoutV2,
+      },
+    });
     AWS.mock("ACM", "describeCertificate", describeCertificateFake);
 
     const deleteCertificateFake = sinon.fake.resolves({});
@@ -935,6 +987,11 @@ describe("DNS Validated Certificate Handler", () => {
       CertificateSummaryList: [
         {
           DomainName: `${testEnvName}.${testAppName}.${testDomainName}`,
+          CertificateArn: testCertificateArn,
+        },
+        {
+          DomainName: `${testEnvName}.${testAppName}.${testDomainName}`,
+          CertificateArn: testOtherCertificateArn,
         },
       ],
     });
@@ -988,129 +1045,10 @@ describe("DNS Validated Certificate Handler", () => {
           })
         );
         sinon.assert.calledWith(listCertificatesFake, sinon.match({}));
-        sinon.assert.calledWith(
-          changeResourceRecordSetsFake,
-          sinon.match({
-            ChangeBatch: testDeleteRecordChangebatch1,
-            HostedZoneId: testHostedZoneId,
-          })
-        );
-        sinon.assert.calledWith(
-          changeResourceRecordSetsFake,
-          sinon.match({
-            ChangeBatch: testDeleteRecordChangebatch2,
-            HostedZoneId: testAppHostedZoneId,
-          })
-        );
-        sinon.assert.calledWith(
-          changeResourceRecordSetsFake,
-          sinon.match({
-            ChangeBatch: testDeleteRecordChangebatch3,
-            HostedZoneId: testAppHostedZoneId,
-          })
-        );
-        sinon.assert.calledWith(
-          listHostedZonesByNameFake,
-          sinon.match({
-            DNSName: `${testAppName}.${testDomainName}`,
-            MaxItems: "1",
-          })
-        );
-        sinon.assert.calledWith(
-          listHostedZonesByNameFake,
-          sinon.match({
-            DNSName: `${testDomainName}`,
-            MaxItems: "1",
-          })
-        );
-        sinon.assert.calledWith(
-          deleteCertificateFake,
-          sinon.match({
-            CertificateArn: testCertificateArn,
-          })
-        );
-        expect(request.isDone()).toBe(true);
-      });
-  });
-
-  test("Delete operation deletes the new cert but not the last", () => {
-    const describeCertificateFake = sinon.fake.resolves({
-      Certificate: {
-        CertificateArn: testCertificateArn,
-        DomainValidationOptions: newCertValidateOptions,
-      },
-    });
-    AWS.mock("ACM", "describeCertificate", describeCertificateFake);
-
-    const deleteCertificateFake = sinon.fake.resolves({});
-    AWS.mock("ACM", "deleteCertificate", deleteCertificateFake);
-
-    const listCertificatesFake = sinon.stub();
-    listCertificatesFake.resolves({
-      CertificateSummaryList: [
-        {
-          DomainName: `${testEnvName}.${testAppName}.${testDomainName}`,
-        },
-        {
-          DomainName: `${testEnvName}.${testAppName}.${testDomainName}`,
-        },
-      ],
-    });
-    AWS.mock("ACM", "listCertificates", listCertificatesFake);
-
-    const changeResourceRecordSetsFake = sinon.fake.resolves({
-      ChangeInfo: {
-        Id: "bogus",
-      },
-    });
-    AWS.mock(
-      "Route53",
-      "changeResourceRecordSets",
-      changeResourceRecordSetsFake
-    );
-
-    const listHostedZonesByNameFake = sinon.fake.resolves({
-      HostedZones: [
-        {
-          Id: `/hostedzone/${testAppHostedZoneId}`,
-        },
-      ],
-    });
-    AWS.mock("Route53", "listHostedZonesByName", listHostedZonesByNameFake);
-
-    const request = nock(ResponseURL)
-      .put("/", (body) => {
-        return body.Status === "SUCCESS";
-      })
-      .reply(200);
-
-    return LambdaTester(handler.certificateRequestHandler)
-      .event({
-        RequestType: "Delete",
-        RequestId: testRequestId,
-        PhysicalResourceId: testCertificateArn,
-        ResourceProperties: {
-          AppName: testAppName,
-          EnvName: testEnvName,
-          DomainName: testDomainName,
-          EnvHostedZoneId: testHostedZoneId,
-          Region: "us-east-1",
-          RootDNSRole: testRootDNSRole,
-        },
-      })
-      .expectResolve(() => {
         sinon.assert.calledWith(
           describeCertificateFake,
           sinon.match({
-            CertificateArn: testCertificateArn,
-          })
-        );
-        sinon.assert.calledWith(listCertificatesFake, sinon.match({}));
-        sinon.assert.calledWith(
-          changeResourceRecordSetsFake,
-          sinon.match({
-            ChangeBatch: testDeleteRecordChangebatch2,
-            HostedZoneId: testAppHostedZoneId,
+            CertificateArn: testOtherCertificateArn,
           })
         );
         sinon.assert.calledWith(
@@ -1120,13 +1058,6 @@ describe("DNS Validated Certificate Handler", () => {
             HostedZoneId: testAppHostedZoneId,
           })
         );
-        sinon.assert.calledWith(
-          listHostedZonesByNameFake,
-          sinon.match({
-            DNSName: `${testAppName}.${testDomainName}`,
-            MaxItems: "1",
-          })
-        );
         sinon.assert.calledWith(
           listHostedZonesByNameFake,
           sinon.match({
