@@ -8,6 +8,7 @@ import (
 	"fmt"
 	"os"
 	"path/filepath"
+	"regexp"
 	"strings"
 
 	"github.com/aws/aws-sdk-go/aws"
@@ -346,8 +347,8 @@ func buildArgs(name, imageTag, copilotDir string, unmarshaledManifest interface{
 func (o *deploySvcOpts) pushAddonsTemplateToS3Bucket() (string, error) {
 	template, err := o.addons.Template()
 	if err != nil {
-		var notExistErr *addon.ErrAddonsDirNotExist
-		if errors.As(err, &notExistErr) {
+		var notFoundErr *addon.ErrAddonsNotFound
+		if errors.As(err, &notFoundErr) {
 			// addons doesn't exist for service, the url is empty.
 			return "", nil
 		}
@@ -424,14 +425,10 @@ func (o *deploySvcOpts) stackConfiguration(addonsURL string) (cloudformation.Sta
 	var conf cloudformation.StackConfiguration
 	switch t := mft.(type) {
 	case *manifest.LoadBalancedWebService:
-		if err := o.validateAppVersion(t); err != nil {
-			log.Errorf(`Cannot deploy service %s because the application version is incompatible.
-To upgrade the application, please run %s first (see https://aws.github.io/copilot-cli/docs/credentials/#application-credentials).
-`, aws.StringValue(t.Name),
-				color.HighlightCode("copilot app upgrade"))
-			return nil, err
-		}
 		if o.targetApp.RequiresDNSDelegation() {
+			if err := validateAlias(aws.StringValue(t.Name), aws.StringValue(t.Alias), o.targetApp, o.envName, o.appVersionGetter); err != nil {
+				return nil, err
+			}
 			conf, err = stack.NewHTTPSLoadBalancedWebService(t, o.targetEnvironment.Name, o.targetEnvironment.App, *rc)
 		} else {
 			conf, err = stack.NewLoadBalancedWebService(t, o.targetEnvironment.Name, o.targetEnvironment.App, *rc)
@@ -461,19 +458,56 @@ func (o *deploySvcOpts) deploySvc(addonsURL string) error {
 	return nil
 }
 
-func (o *deploySvcOpts) validateAppVersion(svc *manifest.LoadBalancedWebService) error {
-	var appVersion string
+func validateAlias(svcName, alias string, app *config.Application, envName string, appVersionGetter versionGetter) error {
+	if alias == "" {
+		return nil
+	}
+	if err := validateAppVersion(alias, app, appVersionGetter); err != nil {
+		log.Errorf(`Cannot deploy service %s because the application version is incompatible.
+To upgrade the application, please run %s first (see https://aws.github.io/copilot-cli/docs/credentials/#application-credentials).
+`, svcName,
+			color.HighlightCode("copilot app upgrade"))
+		return err
+	}
+	// Alias should be within either env, app, or root hosted zone.
+	var regEnvHostedZone, regAppHostedZone, regRootHostedZone *regexp.Regexp
 	var err error
-	if aws.StringValue(svc.Alias) != "" && o.targetApp.RequiresDNSDelegation() {
-		appVersion, err = o.appVersionGetter.Version()
-		if err != nil {
-			return fmt.Errorf("get version for app %s: %w", o.appName, err)
-		}
-		diff := semver.Compare(appVersion, deploy.AliasLeastAppTemplateVersion)
-		if diff < 0 {
-			return fmt.Errorf(`enable "http.alias": the application version should be at least %s`, deploy.AliasLeastAppTemplateVersion)
+	if regEnvHostedZone, err = regexp.Compile(fmt.Sprintf(`^([^\.]+\.)?%s.%s.%s`, envName, app.Name, app.Domain)); err != nil {
+		return err
+	}
+	if regAppHostedZone, err = regexp.Compile(fmt.Sprintf(`^([^\.]+\.)?%s.%s`, app.Name, app.Domain)); err != nil {
+		return err
+	}
+	if regRootHostedZone, err = regexp.Compile(fmt.Sprintf(`^([^\.]+\.)?%s`, app.Domain)); err != nil {
+		return err
+	}
+	for _, re := range []*regexp.Regexp{regEnvHostedZone, regAppHostedZone, regRootHostedZone} {
+		if re.MatchString(alias) {
+			return nil
 		}
 	}
+	log.Errorf(`%s must match one of the following patterns:
+- %s.%s.%s,
+- <name>.%s.%s.%s,
+- %s.%s,
+- <name>.%s.%s,
+- %s,
+- <name>.%s
+`, color.HighlightCode("http.alias"), envName, app.Name, app.Domain, envName,
+		app.Name, app.Domain, app.Name, app.Domain, app.Name,
+		app.Domain, app.Domain, app.Domain)
+	return fmt.Errorf("alias is not supported in hosted zones not managed by Copilot")
+}
+
+func validateAppVersion(alias string, app *config.Application, appVersionGetter versionGetter) error {
+	appVersion, err := appVersionGetter.Version()
+	if err != nil {
+		return fmt.Errorf("get version for app %s: %w", app.Name, err)
+	}
+	diff := semver.Compare(appVersion, deploy.AliasLeastAppTemplateVersion)
+	if diff < 0 {
+		return fmt.Errorf(`alias is not compatible with application versions below %s`, deploy.AliasLeastAppTemplateVersion)
+	}
 	return nil
 }
 
